# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/consumer.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/api/consumer.proto",
    package="google.api",
    syntax="proto3",
    serialized_options=b"\n\016com.google.apiB\rConsumerProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig",
    serialized_pb=b'\n\x19google/api/consumer.proto\x12\ngoogle.api"=\n\x11ProjectProperties\x12(\n\nproperties\x18\x01 \x03(\x0b\x32\x14.google.api.Property"\xac\x01\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0e\x32!.google.api.Property.PropertyType\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t"L\n\x0cPropertyType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\t\n\x05INT64\x10\x01\x12\x08\n\x04\x42OOL\x10\x02\x12\n\n\x06STRING\x10\x03\x12\n\n\x06\x44OUBLE\x10\x04\x42h\n\x0e\x63om.google.apiB\rConsumerProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfigb\x06proto3',
)


_PROPERTY_PROPERTYTYPE = _descriptor.EnumDescriptor(
    name="PropertyType",
    full_name="google.api.Property.PropertyType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="UNSPECIFIED", index=0, number=0, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="INT64", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="BOOL", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="STRING", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="DOUBLE", index=4, number=4, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=201,
    serialized_end=277,
)
_sym_db.RegisterEnumDescriptor(_PROPERTY_PROPERTYTYPE)


_PROJECTPROPERTIES = _descriptor.Descriptor(
    name="ProjectProperties",
    full_name="google.api.ProjectProperties",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="properties",
            full_name="google.api.ProjectProperties.properties",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=41,
    serialized_end=102,
)


_PROPERTY = _descriptor.Descriptor(
    name="Property",
    full_name="google.api.Property",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.api.Property.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.api.Property.type",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.api.Property.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_PROPERTY_PROPERTYTYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=105,
    serialized_end=277,
)

_PROJECTPROPERTIES.fields_by_name["properties"].message_type = _PROPERTY
_PROPERTY.fields_by_name["type"].enum_type = _PROPERTY_PROPERTYTYPE
_PROPERTY_PROPERTYTYPE.containing_type = _PROPERTY
DESCRIPTOR.message_types_by_name["ProjectProperties"] = _PROJECTPROPERTIES
DESCRIPTOR.message_types_by_name["Property"] = _PROPERTY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProjectProperties = _reflection.GeneratedProtocolMessageType(
    "ProjectProperties",
    (_message.Message,),
    {
        "DESCRIPTOR": _PROJECTPROPERTIES,
        "__module__": "google.api.consumer_pb2"
        # @@protoc_insertion_point(class_scope:google.api.ProjectProperties)
    },
)
_sym_db.RegisterMessage(ProjectProperties)

Property = _reflection.GeneratedProtocolMessageType(
    "Property",
    (_message.Message,),
    {
        "DESCRIPTOR": _PROPERTY,
        "__module__": "google.api.consumer_pb2"
        # @@protoc_insertion_point(class_scope:google.api.Property)
    },
)
_sym_db.RegisterMessage(Property)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/resource.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/api/resource.proto",
    package="google.api",
    syntax="proto3",
    serialized_options=b"\n\016com.google.apiB\rResourceProtoP\001ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\370\001\001\242\002\004GAPI",
    serialized_pb=b'\n\x19google/api/resource.proto\x12\ngoogle.api\x1a google/protobuf/descriptor.proto"\xff\x01\n\x12ResourceDescriptor\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07pattern\x18\x02 \x03(\t\x12\x12\n\nname_field\x18\x03 \x01(\t\x12\x37\n\x07history\x18\x04 \x01(\x0e\x32&.google.api.ResourceDescriptor.History\x12\x0e\n\x06plural\x18\x05 \x01(\t\x12\x10\n\x08singular\x18\x06 \x01(\t"[\n\x07History\x12\x17\n\x13HISTORY_UNSPECIFIED\x10\x00\x12\x1d\n\x19ORIGINALLY_SINGLE_PATTERN\x10\x01\x12\x18\n\x14\x46UTURE_MULTI_PATTERN\x10\x02"5\n\x11ResourceReference\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x12\n\nchild_type\x18\x02 \x01(\t:Y\n\x12resource_reference\x12\x1d.google.protobuf.FieldOptions\x18\x9f\x08 \x01(\x0b\x32\x1d.google.api.ResourceReference:Z\n\x13resource_definition\x12\x1c.google.protobuf.FileOptions\x18\x9d\x08 \x03(\x0b\x32\x1e.google.api.ResourceDescriptor:R\n\x08resource\x12\x1f.google.protobuf.MessageOptions\x18\x9d\x08 \x01(\x0b\x32\x1e.google.api.ResourceDescriptorBn\n\x0e\x63om.google.apiB\rResourceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\xf8\x01\x01\xa2\x02\x04GAPIb\x06proto3',
    dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR],
)


RESOURCE_REFERENCE_FIELD_NUMBER = 1055
resource_reference = _descriptor.FieldDescriptor(
    name="resource_reference",
    full_name="google.api.resource_reference",
    index=0,
    number=1055,
    type=11,
    cpp_type=10,
    label=1,
    has_default_value=False,
    default_value=None,
    message_type=None,
    enum_type=None,
    containing_type=None,
    is_extension=True,
    extension_scope=None,
    serialized_options=None,
    file=DESCRIPTOR,
)
RESOURCE_DEFINITION_FIELD_NUMBER = 1053
resource_definition = _descriptor.FieldDescriptor(
    name="resource_definition",
    full_name="google.api.resource_definition",
    index=1,
    number=1053,
    type=11,
    cpp_type=10,
    label=3,
    has_default_value=False,
    default_value=[],
    message_type=None,
    enum_type=None,
    containing_type=None,
    is_extension=True,
    extension_scope=None,
    serialized_options=None,
    file=DESCRIPTOR,
)
RESOURCE_FIELD_NUMBER = 1053
resource = _descriptor.FieldDescriptor(
    name="resource",
    full_name="google.api.resource",
    index=2,
    number=1053,
    type=11,
    cpp_type=10,
    label=1,
    has_default_value=False,
    default_value=None,
    message_type=None,
    enum_type=None,
    containing_type=None,
    is_extension=True,
    extension_scope=None,
    serialized_options=None,
    file=DESCRIPTOR,
)

_RESOURCEDESCRIPTOR_HISTORY = _descriptor.EnumDescriptor(
    name="History",
    full_name="google.api.ResourceDescriptor.History",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="HISTORY_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ORIGINALLY_SINGLE_PATTERN",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="FUTURE_MULTI_PATTERN",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=240,
    serialized_end=331,
)
_sym_db.RegisterEnumDescriptor(_RESOURCEDESCRIPTOR_HISTORY)


_RESOURCEDESCRIPTOR = _descriptor.Descriptor(
    name="ResourceDescriptor",
    full_name="google.api.ResourceDescriptor",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.api.ResourceDescriptor.type",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="pattern",
            full_name="google.api.ResourceDescriptor.pattern",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="name_field",
            full_name="google.api.ResourceDescriptor.name_field",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="history",
            full_name="google.api.ResourceDescriptor.history",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="plural",
            full_name="google.api.ResourceDescriptor.plural",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="singular",
            full_name="google.api.ResourceDescriptor.singular",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_RESOURCEDESCRIPTOR_HISTORY],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=76,
    serialized_end=331,
)


_RESOURCEREFERENCE = _descriptor.Descriptor(
    name="ResourceReference",
    full_name="google.api.ResourceReference",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.api.ResourceReference.type",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="child_type",
            full_name="google.api.ResourceReference.child_type",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=333,
    serialized_end=386,
)

_RESOURCEDESCRIPTOR.fields_by_name["history"].enum_type = _RESOURCEDESCRIPTOR_HISTORY
_RESOURCEDESCRIPTOR_HISTORY.containing_type = _RESOURCEDESCRIPTOR
DESCRIPTOR.message_types_by_name["ResourceDescriptor"] = _RESOURCEDESCRIPTOR
DESCRIPTOR.message_types_by_name["ResourceReference"] = _RESOURCEREFERENCE
DESCRIPTOR.extensions_by_name["resource_reference"] = resource_reference
DESCRIPTOR.extensions_by_name["resource_definition"] = resource_definition
DESCRIPTOR.extensions_by_name["resource"] = resource
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ResourceDescriptor = _reflection.GeneratedProtocolMessageType(
    "ResourceDescriptor",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOURCEDESCRIPTOR,
        "__module__": "google.api.resource_pb2"
        # @@protoc_insertion_point(class_scope:google.api.ResourceDescriptor)
    },
)
_sym_db.RegisterMessage(ResourceDescriptor)

ResourceReference = _reflection.GeneratedProtocolMessageType(
    "ResourceReference",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOURCEREFERENCE,
        "__module__": "google.api.resource_pb2"
        # @@protoc_insertion_point(class_scope:google.api.ResourceReference)
    },
)
_sym_db.RegisterMessage(ResourceReference)

resource_reference.message_type = _RESOURCEREFERENCE
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(
    resource_reference
)
resource_definition.message_type = _RESOURCEDESCRIPTOR
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(
    resource_definition
)
resource.message_type = _RESOURCEDESCRIPTOR
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(resource)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/longrunning/operations.proto
from google.longrunning.operations_proto_pb2 import *
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class OperationsStub(object):
    """Manages long-running operations with an API service.

  When an API method normally takes long time to complete, it can be designed
  to return [Operation][google.longrunning.Operation] to the client, and the client can use this
  interface to receive the real response asynchronously by polling the
  operation resource, or pass the operation resource to another API (such as
  Google Cloud Pub/Sub API) to receive the response.  Any API service that
  returns long-running operations should implement the `Operations` interface
  so developers can have a consistent client experience.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.GetOperation = channel.unary_unary(
            "/google.longrunning.Operations/GetOperation",
            request_serializer=GetOperationRequest.SerializeToString,
            response_deserializer=Operation.FromString,
        )
        self.ListOperations = channel.unary_unary(
            "/google.longrunning.Operations/ListOperations",
            request_serializer=ListOperationsRequest.SerializeToString,
            response_deserializer=ListOperationsResponse.FromString,
        )
        self.CancelOperation = channel.unary_unary(
            "/google.longrunning.Operations/CancelOperation",
            request_serializer=CancelOperationRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.DeleteOperation = channel.unary_unary(
            "/google.longrunning.Operations/DeleteOperation",
            request_serializer=DeleteOperationRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
